==========================
CLT Calculation for Python
==========================


.. image:: https://img.shields.io/pypi/v/clt_py.svg
        :target: https://pypi.python.org/pypi/clt_py

.. image:: https://travis-ci.com/axelschmidt91/clt_py.svg?branch=master
        :target: https://travis-ci.com/axelschmidt91/clt_py

.. image:: https://readthedocs.org/projects/clt-py/badge/?version=latest
        :target: https://clt-py.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/axelschmidt91/clt_py/shield.svg
        :target: https://pyup.io/repos/github/axelschmidt91/clt_py/
        :alt: Updates

.. image:: https://coveralls.io/repos/github/axelschmidt91/clt_py/badge.svg?branch=master
        :target: https://coveralls.io/github/axelschmidt91/clt_py?branch=master

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
        :target: https://github.com/psf/black



This packages provides methodes for calculating fiber-reinforced materials.


* Free software: MIT license
* Documentation: https://clt-py.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
